<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kmplot_shell" version="1">
	<MenuBar>
		<Menu noMerge="1" name="file"><text>&amp;File</text>
			<Action name="file_new"/>
			<Separator/>
			<Action name="file_open"/>
			<Merge/>
			<Separator/>
			<Action name="file_quit"/>
		</Menu>
		<Merge/>
		<Menu name="help"><text>&amp;Help</text>
			<DefineGroup name="names_group" />
		</Menu>
	</MenuBar>
	<ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
		<Action name="file_new"/>
		<Action name="file_open"/>
		<Merge/>
	</ToolBar>
</kpartgui>
