<!DOCTYPE kpartgui>
<kpartgui name="kmplot" version="9">
	<MenuBar>
 		<Menu name="file">
			<Action name="file_save_as"/>
			<Separator/>
			<Action name="export"/>
		</Menu>
		<Menu name="edit"><text>&amp;Edit</text>
			<Action name="edit_undo"/>
			<Action name="edit_redo"/>
			<Separator/>
			<Action name="editconstants"/>
		</Menu>
		<Menu name="view"><text>&amp;View</text>
			<Action name="zoom_in"/>
			<Action name="zoom_out"/>
			<Action name="zoom_trig"/>
			<Separator/>
			<Action name="reset_view"/>
			<Action name="editaxes"/>
			<Separator/>
			<Action name="options_configure_show_sliders"/>
			<Separator />
		</Menu>
		<Menu name="tools"><text>&amp;Tools</text>
			<Action name="calculator"/>
			<Action name="grapharea"/>
			<Action name="maximumvalue"/>
			<Action name="minimumvalue"/>
		</Menu>
		<Menu name="settings">
			<Action name="options_configure"/>
		</Menu>
		<Menu name="help"><text>&amp;Help</text>
			<Action name="names" group="names_group"/>
		</Menu>
	</MenuBar>
	<ToolBar name="mainToolBar">
		<Action name="zoom_in"/>
		<Action name="zoom_out"/>
		<Action name="reset_view"/>
		<Separator />
		<Action name="helpcontents"/>
	</ToolBar>
</kpartgui>
